@@ -451,6 +451,11 @@ impl<'a> TiledInputPart<'a> {
     /// Reads the tile with tile coordinates `(dx, dy)`, and level number `(lx, ly)`,
     /// and stores it in the current frame buffer.
     ///
+    /// # Safety
+    /// You must ensure the the [`FrameBuffer`] attached to this file by
+    /// [`set_frame_buffer()`](TiledInputPart::set_frame_buffer) has valid slices
+    /// for the channels to be read.
+    ///
     ///   # Errors
     /// * [`Error::InvalidArgument`] - if dx does not lie in the interval [0, num_x_tiles(lx)-1]
     /// * [`Error::InvalidArgument`] - if dy does not lie in the interval [0, num_y_tiles(ly)-1]
@@ -460,23 +465,26 @@ impl<'a> TiledInputPart<'a> {
     /// * [`Error::Io`] - if there is an error reading data from the file
     /// * [`Error::Base`] - if any other error occurs
     ///
-    pub fn read_tile(
+    pub unsafe fn read_tile(
         &mut self,
         dx: i32,
         dy: i32,
         lx: i32,
         ly: i32,
     ) -> Result<()> {
-        unsafe {
-            sys::Imf_TiledInputPart_readTile(&mut self.inner, dx, dy, lx, ly)
-                .into_result()?;
-        }
+        sys::Imf_TiledInputPart_readTile(&mut self.inner, dx, dy, lx, ly)
+            .into_result()?;
         Ok(())
     }
 
     /// Reads the sample counts in tile range with coordinates `(dx1, dy1)`, to `(dx2, dy2)` and level number `(lx, ly)`,
     /// and stores it in the current frame buffer.
     ///
+    /// # Safety
+    /// You must ensure the the [`FrameBuffer`] attached to this file by
+    /// [`set_frame_buffer()`](TiledInputPart::set_frame_buffer) has valid slices
+    /// for the channels to be read.
+    ///
     ///   # Errors
     /// * [`Error::InvalidArgument`] - if dx does not lie in the interval [0, num_x_tiles(lx)-1]
     /// * [`Error::InvalidArgument`] - if dy does not lie in the interval [0, num_y_tiles(ly)-1]
@@ -486,7 +494,7 @@ impl<'a> TiledInputPart<'a> {
     /// * [`Error::Io`] - if there is an error reading data from the file
     /// * [`Error::Base`] - if any other error occurs
     ///
-    pub fn read_tiles(
+    pub unsafe fn read_tiles(
         &mut self,
         dx1: i32,
         dx2: i32,
@@ -495,18 +503,16 @@ impl<'a> TiledInputPart<'a> {
         lx: i32,
         ly: i32,
     ) -> Result<()> {
-        unsafe {
-            sys::Imf_TiledInputPart_readTiles(
-                &mut self.inner,
-                dx1,
-                dx2,
-                dy1,
-                dy2,
-                lx,
-                ly,
-            )
-            .into_result()?;
-        }
+        sys::Imf_TiledInputPart_readTiles(
+            &mut self.inner,
+            dx1,
+            dx2,
+            dy1,
+            dy2,
+            lx,
+            ly,
+        )
+        .into_result()?;
         Ok(())
     }
 }
@@ -783,7 +789,9 @@ mod tests {
         let mut tiled_input_part = super::TiledInputPart::new(&input, 0);
         let frame_buffer = FrameBuffer::new();
         tiled_input_part.set_frame_buffer(&frame_buffer).unwrap();
-        tiled_input_part.read_tile(0, 0, 0, 0).unwrap();
+        unsafe {
+            tiled_input_part.read_tile(0, 0, 0, 0).unwrap();
+        }
     }
 
     #[test]
@@ -791,9 +799,11 @@ mod tests {
     fn test_tiledinputpart_read_tile_failure_invalid_level_and_frame_buffer() {
         let input = MultiPartInputFile::new(&*SRC_IMAGE_PATH, 0, true).unwrap();
         let mut tiled_input_part = super::TiledInputPart::new(&input, 0);
-        tiled_input_part
-            .read_tile(i32::MIN, i32::MIN, i32::MIN, i32::MIN)
-            .unwrap();
+        unsafe {
+            tiled_input_part
+                .read_tile(i32::MIN, i32::MIN, i32::MIN, i32::MIN)
+                .unwrap();
+        }
     }
 
     #[test]
@@ -802,7 +812,9 @@ mod tests {
         let mut tiled_input_part = super::TiledInputPart::new(&input, 0);
         let frame_buffer = FrameBuffer::new();
         tiled_input_part.set_frame_buffer(&frame_buffer).unwrap();
-        tiled_input_part.read_tiles(0, 0, 0, 0, 0, 0).unwrap();
+        unsafe {
+            tiled_input_part.read_tiles(0, 0, 0, 0, 0, 0).unwrap();
+        }
     }
 
     #[test]
@@ -810,15 +822,17 @@ mod tests {
     fn test_tiledinputpart_read_tiles_failure_invalid_level_and_frame_buffer() {
         let input = MultiPartInputFile::new(&*SRC_IMAGE_PATH, 0, true).unwrap();
         let mut tiled_input_part = super::TiledInputPart::new(&input, 0);
-        tiled_input_part
-            .read_tiles(
-                i32::MIN,
-                i32::MIN,
-                i32::MIN,
-                i32::MIN,
-                i32::MIN,
-                i32::MIN,
-            )
-            .unwrap();
+        unsafe {
+            tiled_input_part
+                .read_tiles(
+                    i32::MIN,
+                    i32::MIN,
+                    i32::MIN,
+                    i32::MIN,
+                    i32::MIN,
+                    i32::MIN,
+                )
+                .unwrap();
+        }
     }
 }
